import { NextRequest, NextResponse } from 'next/server';
import { ZodObject, ZodRawShape, z } from 'zod';
import { EmptyZodObject, NextJSRequestHandler, RouteParamsBase } from './handler-types';
import { Expand, ExtendZodObject, IgnoreRequestBody, InferBodyType, MergeValidBodyTypes, MergeZodObjects, ValidBodyTypes } from './type-helpers';
import { UseFinishRequest } from './use-finish-request';
export type ParseErrorHandler<RouteParams extends RouteParamsBase> = (data: {
    req: NextRequest;
    params: RouteParams;
    error: any;
}) => Promise<NextResponse> | NextResponse;
export declare class BaseRequestHandler<RouteParams extends RouteParamsBase = object, QueryParams extends z.SomeZodObject = EmptyZodObject, Cookies extends z.SomeZodObject = EmptyZodObject, Body extends ValidBodyTypes = IgnoreRequestBody> extends UseFinishRequest<RouteParams, QueryParams, Cookies, Body, object, object> {
    private queryParamsSchema;
    private bodySchema;
    private cookieSchema;
    private parseErrorHandler;
    getBaseHandler(): this;
    getContextFunction(): () => {};
    constructor(queryParamsSchema: QueryParams, cookieSchema: Cookies, bodySchema: Body, parseErrorHandler?: ParseErrorHandler<RouteParams>);
    params<RP extends string>(..._params: readonly RP[]): BaseRequestHandler<Expand<{
        [K in RP]: string;
    } & RouteParams>, QueryParams, Cookies, Body>;
    onParseError(handler: ParseErrorHandler<RouteParams>): BaseRequestHandler<RouteParams, QueryParams, Cookies, Body>;
    get parseErrorHandlerFunction(): ParseErrorHandler<RouteParams> | undefined;
    catchAllParams<RP extends string>(_segment: RP): BaseRequestHandler<Expand<{
        [K in RP]: string[];
    } & RouteParams>, QueryParams, Cookies, Body>;
    query<O extends z.ZodRawShape>(schema: O | ZodObject<O>): BaseRequestHandler<RouteParams, ExtendZodObject<QueryParams, O>, Cookies, Body>;
    cookies<O extends z.ZodRawShape>(schema: O | ZodObject<O>): BaseRequestHandler<RouteParams, QueryParams, ExtendZodObject<Cookies, O>, Body>;
    body<O>(schema: O): O extends ValidBodyTypes ? BaseRequestHandler<RouteParams, QueryParams, Cookies, MergeValidBodyTypes<Body, O>> : O extends ZodRawShape ? BaseRequestHandler<RouteParams, QueryParams, Cookies, MergeValidBodyTypes<Body, ZodObject<O>>> : never;
    extend<R extends RouteParamsBase, Q extends z.AnyZodObject, C extends z.AnyZodObject, B extends ValidBodyTypes>(other: BaseRequestHandler<R, Q, C, B>): BaseRequestHandler<RouteParams & R, MergeZodObjects<QueryParams, Q>, MergeZodObjects<Cookies, C>, MergeValidBodyTypes<Body, B>>;
    parseRequest(...[req, { params }]: Parameters<NextJSRequestHandler<RouteParams>>): Promise<{
        query: z.infer<QueryParams>;
        body: InferBodyType<Body>;
        cookies: z.infer<Cookies>;
        params: RouteParams;
        rawBody: string;
    }>;
    getRequirements(): this;
}
