import { NextRequest, NextResponse } from 'next/server';
import { z } from 'zod';
import { ContextBase, RequestHandler, RouteParamsBase } from './handler-types';
import { InferBodyType, ValidBodyTypes } from './type-helpers';
import { UseContext } from './use-context';
export declare abstract class UseFinishRequest<RouteParams extends RouteParamsBase, QueryParams extends z.SomeZodObject, Cookies extends z.SomeZodObject, Body extends ValidBodyTypes, InputContext extends ContextBase, OutputContext extends ContextBase> extends UseContext<RouteParams, QueryParams, Cookies, Body, InputContext, OutputContext> {
    protected constructor();
    private finish;
    get<D extends object>(handler: RequestHandler<RouteParams, z.TypeOf<QueryParams>, z.TypeOf<Cookies>, undefined, OutputContext, D>): (req: NextRequest, options: any, _typeInfo?: {
        method: "GET";
        body: undefined;
        params: RouteParams;
        query: z.TypeOf<QueryParams>;
        cookies: z.TypeOf<Cookies>;
        data: D;
    } | undefined) => Promise<NextResponse>;
    post<D extends object>(handler: RequestHandler<RouteParams, z.TypeOf<QueryParams>, z.TypeOf<Cookies>, InferBodyType<Body>, OutputContext, D>): (req: NextRequest, options: any, _typeInfo?: {
        method: "POST";
        body: InferBodyType<Body>;
        params: RouteParams;
        query: z.TypeOf<QueryParams>;
        cookies: z.TypeOf<Cookies>;
        data: D;
    } | undefined) => Promise<NextResponse>;
    put<D extends object>(handler: RequestHandler<RouteParams, z.TypeOf<QueryParams>, z.TypeOf<Cookies>, InferBodyType<Body>, OutputContext, D>): (req: NextRequest, options: any, _typeInfo?: {
        method: "PUT";
        body: InferBodyType<Body>;
        params: RouteParams;
        query: z.TypeOf<QueryParams>;
        cookies: z.TypeOf<Cookies>;
        data: D;
    } | undefined) => Promise<NextResponse>;
    patch<D extends object>(handler: RequestHandler<RouteParams, z.TypeOf<QueryParams>, z.TypeOf<Cookies>, InferBodyType<Body>, OutputContext, D>): (req: NextRequest, options: any, _typeInfo?: {
        method: "PATCH";
        body: InferBodyType<Body>;
        params: RouteParams;
        query: z.TypeOf<QueryParams>;
        cookies: z.TypeOf<Cookies>;
        data: D;
    } | undefined) => Promise<NextResponse>;
    delete<D extends object>(handler: RequestHandler<RouteParams, z.TypeOf<QueryParams>, z.TypeOf<Cookies>, undefined, OutputContext, D>): (req: NextRequest, options: any, _typeInfo?: {
        method: "DELETE";
        body: undefined;
        params: RouteParams;
        query: z.TypeOf<QueryParams>;
        cookies: z.TypeOf<Cookies>;
        data: D;
    } | undefined) => Promise<NextResponse>;
    head<D extends object>(handler: RequestHandler<RouteParams, z.TypeOf<QueryParams>, z.TypeOf<Cookies>, undefined, OutputContext, D>): (req: NextRequest, options: any, _typeInfo?: {
        method: "HEAD";
        body: undefined;
        params: RouteParams;
        query: z.TypeOf<QueryParams>;
        cookies: z.TypeOf<Cookies>;
        data: D;
    } | undefined) => Promise<NextResponse>;
    options<D extends object>(handler: RequestHandler<RouteParams, z.TypeOf<QueryParams>, z.TypeOf<Cookies>, undefined, OutputContext, D>): (req: NextRequest, options: any, _typeInfo?: {
        method: "OPTIONS";
        body: undefined;
        params: RouteParams;
        query: z.TypeOf<QueryParams>;
        cookies: z.TypeOf<Cookies>;
        data: D;
    } | undefined) => Promise<NextResponse>;
}
